Learn R Programming

ResistorArray (version 1.0-33)

Wu: Wu's resistance matrix

Description

Returns a matrix M with M[i,j] is the resistance between nodes i and j.

Usage

Wu(L)

Value

Returns a matrix of the same size as L, but whose elements are the effective resistance between the nodes.

Arguments

L

Laplacian conductance matrix

Author

Robin K. S. Hankin

Details

Evaluates Wu's resistance matrix, as per his theorem on page 6656.

References

F. Y. Wu, 2004. “Theory of resistor networks: the two point resistance”, Journal of Physics A, volume 37, pp6653-6673

See Also

resistance

Examples

Run this code

Wu(cube())

Wu(cube())[1,2] - resistance(cube(),1,2)

Wu(series(1:7))  # observe how resistance between, say, nodes 2
                 # and 5 is 9 (=2+3+4)

Run the code above in your browser using DataLab